@@ -33,6 +33,55 @@ OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
+__version__ = '0.4.2'
+__author__ = 'Qing Yu <qingyu0815@foxmail.com>'
+
+# module level doc-string
+__doc__ = """
+TransBigData - A Python package develop for transportation spatio-temporal big
+data processing, analysis and visualization.
+=====================================================================
+
+`TransBigData` is a Python package developed for transportation spatio-temporal
+big data processing, analysis and visualization. `TransBigData` provides fast
+and concise methods for processing common transportation spatio-temporal big
+data such as Taxi GPS data, bicycle sharing data and bus GPS data.
+`TransBigData` provides a variety of processing methods for each stage of
+transportation spatio-temporal big data analysis. The code with `TransBigData`
+is clean, efficient, flexible, and easy to use, allowing complex data tasks to
+be achieved withconcise code.
+
+For some specific types of data, `TransBigData` also provides targeted tools
+for specific needs, such as extraction of Origin and Destination(OD) of taxi
+trips from taxi GPS data and identification of arrival and departure
+information from bus GPS data. The latest stable release of the software can
+be installed via pip and full documentation can be found at
+https://transbigdata.readthedocs.io/en/latest/.
+
+Main Features
+-------------
+
+Currently, `TransBigData` mainly provides the following methods:
+
+  - Data Quality: Provides methods to quickly obtain the general information of
+  the dataset, including the data amount the time period and the sampling
+  interval.
+  - Data Preprocess: Provides methods to clean multiple types of data error.
+  - Data Gridding: Provides methods to generate multiple types of geographic
+  grids (Rectangular grids, Hexagonal grids) in the research area. Provides
+  fast algorithms to map GPS data to the generated grids.
+  - Data Aggregating: Provides methods to aggregate GPS data and OD data into
+  geographic polygon.
+  - Data Visualization: Built-in visualization capabilities leverage the
+  visualization package keplergl to interactively visualize data on Jupyter
+  notebook with simple code.
+  - Trajectory Processing: Provides methods to process trajectory data,
+  including generating trajectory linestring from GPS points, and trajectory
+  densification, etc.
+  - Basemap Loading: Provides methods to display Mapbox basemap on matplotlib
+  figures
+"""
+
 from .plotmap import (
     plot_map,
     plotscale,
@@ -51,20 +100,31 @@ from .coordinates import (
     transform_shape
 )
 from .grids import (
+    # new
+    area_to_grid,
+    area_to_params,
+    GPS_to_grid,
+    grid_to_centre,
+    grid_to_polygon,
+    grid_to_area,
+    grid_to_params,
+    grid_params_optimize,
+    # old
     rect_grids,
     grid_params,
-    GPS_to_grids,
     grids_centre,
-    gridid_to_polygon,
     gridid_sjoin_shape,
-    grid_params_optimize,
     regenerate_params,
     geohash_encode,
     geohash_decode,
     geohash_togrid,
+    GPS_to_grids,
+    GPS_to_grids_rect,
     GPS_to_grids_tri,
-    gridid_to_polygon_tri,
     GPS_to_grids_hexa,
+    gridid_to_polygon,
+    gridid_to_polygon_rect,
+    gridid_to_polygon_tri,
     gridid_to_polygon_hexa
 )
 from .gisprocess import (
@@ -129,53 +189,3 @@ from .visualization import (
     visualization_od,
     visualization_data
 )
-
-
-__version__ = '0.3.12'
-__author__ = 'Qing Yu <qingyu0815@foxmail.com>'
-
-# module level doc-string
-__doc__ = """
-TransBigData - A Python package develop for transportation spatio-temporal big
-data processing, analysis and visualization.
-=====================================================================
-
-`TransBigData` is a Python package developed for transportation spatio-temporal
-big data processing, analysis and visualization. `TransBigData` provides fast
-and concise methods for processing common transportation spatio-temporal big
-data such as Taxi GPS data, bicycle sharing data and bus GPS data.
-`TransBigData` provides a variety of processing methods for each stage of
-transportation spatio-temporal big data analysis. The code with `TransBigData`
-is clean, efficient, flexible, and easy to use, allowing complex data tasks to
-be achieved withconcise code.
-
-For some specific types of data, `TransBigData` also provides targeted tools
-for specific needs, such as extraction of Origin and Destination(OD) of taxi
-trips from taxi GPS data and identification of arrival and departure
-information from bus GPS data. The latest stable release of the software can
-be installed via pip and full documentation can be found at
-https://transbigdata.readthedocs.io/en/latest/.
-
-Main Features
--------------
-
-Currently, `TransBigData` mainly provides the following methods:
-
-  - Data Quality: Provides methods to quickly obtain the general information of
-  the dataset, including the data amount the time period and the sampling
-  interval.
-  - Data Preprocess: Provides methods to clean multiple types of data error.
-  - Data Gridding: Provides methods to generate multiple types of geographic
-  grids (Rectangular grids, Hexagonal grids) in the research area. Provides
-  fast algorithms to map GPS data to the generated grids.
-  - Data Aggregating: Provides methods to aggregate GPS data and OD data into
-  geographic polygon.
-  - Data Visualization: Built-in visualization capabilities leverage the
-  visualization package keplergl to interactively visualize data on Jupyter
-  notebook with simple code.
-  - Trajectory Processing: Provides methods to process trajectory data,
-  including generating trajectory linestring from GPS points, and trajectory
-  densification, etc.
-  - Basemap Loading: Provides methods to display Mapbox basemap on matplotlib
-  figures
-"""
